__version__ = '0.0.6'
__version_tuple__ = version_tuple = (0,0,6)
__title__ = "pydeserialize"
__description__ = "Insecure deserialization in python"
__url__ = "https://github.com/joaoviictorti/pyserialize"
__author__ = "joaoviictorti (viictorjj)"
__author_email__ = "joaovictorti08@gmail.com"
__copyright__ = "Copyright João Victor"